Class: Capybarbecue::AsyncDelegateClass
- Inherits:
-
Object
- Object
- Capybarbecue::AsyncDelegateClass
- Defined in:
- lib/capybarbecue/async_delegate_class.rb
Instance Attribute Summary collapse
-
#instance ⇒ Object
readonly
Returns the value of attribute instance.
Instance Method Summary collapse
-
#__async_delegate__ ⇒ Object
This is our hint that we are an AsyncDelegateClass.
-
#initialize(instance, executer, &wait_proc) ⇒ AsyncDelegateClass
constructor
A new instance of AsyncDelegateClass.
- #method_missing(method, *args, &block) ⇒ Object
Constructor Details
#initialize(instance, executer, &wait_proc) ⇒ AsyncDelegateClass
Returns a new instance of AsyncDelegateClass.
5 6 7 8 9 |
# File 'lib/capybarbecue/async_delegate_class.rb', line 5 def initialize(instance, executer, &wait_proc) @instance = instance @executer = executer @wait_proc = wait_proc # Called repeatedly while waiting end |
Dynamic Method Handling
This class handles dynamic methods through the method_missing method
Instance Attribute Details
#instance ⇒ Object (readonly)
Returns the value of attribute instance.
3 4 5 |
# File 'lib/capybarbecue/async_delegate_class.rb', line 3 def instance @instance end |
Instance Method Details
#__async_delegate__ ⇒ Object
This is our hint that we are an AsyncDelegateClass
18 19 20 |
# File 'lib/capybarbecue/async_delegate_class.rb', line 18 def __async_delegate__ true end |